@@ -1,5 +1,5 @@
 /*****************************************************************************
- * RRDtool 1.0.40  Copyright Tobias Oetiker, 1997,1998, 1999
+ * RRDtool 1.0.46  Copyright Tobias Oetiker, 1997,1998, 1999
  *****************************************************************************
  * rrdlib.h   Public header file for librrd
  *****************************************************************************
@@ -47,16 +47,16 @@ typedef enum {
 
 #define TIME_OK NULL
 
-struct time_value {
+struct rrd_time_value {
   timetype type;
   long offset;
   struct tm tm;
 };
 
-char *parsetime(char *spec, struct time_value *ptv);
+char *parsetime(char *spec, struct rrd_time_value *ptv);
 /* END parsetime.h */
 
-int proc_start_end (struct time_value *,  struct time_value *, time_t *, time_t *);
+int proc_start_end (struct rrd_time_value *,  struct rrd_time_value *, time_t *, time_t *);
 
 /* HELPER FUNCTIONS */
 void rrd_set_error(char *,...);
